Use-case examples
=================
Below are some of the applications where PySwarms can be used.
If you wish to check the actual Jupyter Notebooks, please go to this `link <https://github.com/ljvmiranda921/pyswarms/tree/master/examples>`_

.. toctree::

   basic_optimization
   train_neural_network
   feature_subset_selection
   visualization